==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Dokončené</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Os obmedzenia...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>nastaviť os obmedzenia medzi dvoma objektmi</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Self-test...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Spustí bezpečný test pre overenie, či aplikácia funguje správne</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Kreslenie</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>Náčrt</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Náčrt</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Náčrt založený</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Základné</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametrické</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Vzhľad objektu</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Nástroje čiar</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Dokončené</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Os obmedzenia...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>nastaviť os obmedzenia medzi dvoma objektmi</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Self-test...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Spustí bezpečný test pre overenie, či aplikácia funguje správne</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Kreslenie</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>Náčrt</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Náčrt</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Náčrt založený</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Základné</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametrické</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Vzhľad objektu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Nástroje čiar</translation>
    </message>
  </context>
</TS>
